@@ -9,7 +9,7 @@
 #
 package Config::Model::Tk::ListEditor ;
 {
-  $Config::Model::Tk::ListEditor::VERSION = '1.328';
+  $Config::Model::Tk::ListEditor::VERSION = '1.329';
 }
 
 use strict;
@@ -265,7 +265,7 @@ sub push_entry {
     }
     else {
 	# trigger redraw of Tk Tree
-	$cw->reload_tree;
+	$cw->{store_cb}->(1);
     }
 
     my @new_idx = $list->get_all_indexes ;
@@ -292,7 +292,7 @@ sub set_entry {
     $tklist->insert($idx, $data) ;
     $tklist->selectionSet($idx ) ;
     $cw->{list}->fetch_with_id($idx)->store($data) ;
-    $cw->reload_tree ;
+    $cw->{store_cb}->(1) ;
 }
 
 sub add_set_all_b {
@@ -339,7 +339,7 @@ sub set_all_items {
     $tklist->delete(0,'end') ;
     $tklist->insert(0, @list) ;
     $cw->{list}->load_data(\@list) ;
-    $cw->reload_tree ;
+    $cw->{store_cb}->(1) ;
 }
 
 sub sort_content {
@@ -353,7 +353,7 @@ sub sort_content {
     $tklist->delete(0,'end') ;
     $tklist->insert(0, @list) ;
     $list->load_data(\@list) ;
-    $cw->reload_tree ;
+    $cw->{store_cb}->(1) ;
 }
 
 
@@ -412,7 +412,7 @@ sub swap {
     }
 
     $tklist->selectionSet($idb ) ;
-    $cw->reload_tree ;
+    $cw->{store_cb}->(1) ;
 }
 
 sub remove_selection {
@@ -423,8 +423,8 @@ sub remove_selection {
     foreach ($tklist->curselection()) {
 	$logger->debug( "remove_selection: removing index $_" );
 	$list   -> remove($_) ;
-	$cw->reload_tree ;
     }
+    $cw->{store_cb}->(1) ;
 
     # redraw the list content
     $tklist -> delete(0,'end') ;
@@ -436,10 +436,5 @@ sub remove_selection {
     $cw->update_warning($list) ;
 }
 
-sub reload_tree {
-    my $cw = shift ;
-    $cw->{store_cb}->() ;
-}
-
 
 1;
